Module: Radius
- Defined in:
- lib/radius/auth.rb,
lib/radius/packet.rb,
lib/radius/dictionary.rb
Overview
Radius Dictionary file reader Copyright (C) 2002 Rafael R. Sevilla [email protected] This file is part of the Radius Authentication Module for Ruby
The Radius Authentication Module for Ruby is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.
The Radius Authentication Module is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
You should have received a copy of the GNU Lesser General Public License along with the GNU C Library; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
- Author
Rafael R. Sevilla (mailto:[email protected])
- Copyright
Copyright (c) 2002 Rafael R. Sevilla
- License
GNU Lesser General Public License
$Id: dictionary.rb 2 2006-12-17 06:16:21Z dido $
Defined Under Namespace
Classes: Auth, Dictionary, Packet